[![Documentation Status](https://readthedocs.org/projects/kithairon/badge/?version=latest)](https://kithairon.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/cgevans/kithairon/badge.svg?branch=main)](https://coveralls.io/github/cgevans/kithairon?branch=main)

# kithairon: a package Python package for the Echo Liquid Handler

This is the beginnings of a library to assist in using the Labcyte / Beckman Coulter Echo acoustic liquid handler.  If you are reading this readme in this state, then please realize that the library is currently in a likely unusably early state of development.
